@@ -6,8 +6,7 @@ from typing import List, Dict
 
 import ascend.protos.api.api_pb2 as api_pb2
 from ascend.sdk.client import Client
-from ascend.sdk.definitions import (Component, Dataflow, ReadConnector, Transform, WriteConnector,
-                                    ComponentGroup, ComponentIdToUuidMap, ComponentUuidType,
+from ascend.sdk.definitions import (Component, Dataflow, ReadConnector, Transform, WriteConnector, ComponentGroup, ComponentIdToUuidMap, ComponentUuidType,
                                     DataFeed, DataFeedConnector, DataService)
 from openapi_client.exceptions import ApiException
 
@@ -99,8 +98,7 @@ class DataflowApplier:
 
     id_map: ComponentIdToUuidMap = {}
     for dfc in dataflow.data_feed_connectors:
-      resource = DataFeedConnectorApplier(self.client).apply(data_service_id, dataflow.id, dfc,
-                                                             dry_run)
+      resource = DataFeedConnectorApplier(self.client).apply(data_service_id, dataflow.id, dfc, dry_run)
       id_map[dfc.id] = ComponentUuidType(type=dfc.legacy_type(), uuid=resource.uuid)
 
     id_to_component = _component_id_map_from_list(dataflow.components)
@@ -108,7 +106,9 @@ class DataflowApplier:
     for component in dataflow.components:
       g.add_node(component.id)
       for dep in component.dependencies():
-        g.add_edge(component.id, dep)
+        # Only include components in this graph - data feed connectors applied separately.
+        if dep in id_to_component:
+          g.add_edge(component.id, dep)
 
     for component_id in reversed(list(nx.topological_sort(g))):
       component = id_to_component[component_id]
@@ -117,8 +117,7 @@ class DataflowApplier:
       id_map[component.id] = ComponentUuidType(type=component.legacy_type(), uuid=resource.uuid)
 
     for df in dataflow.data_feeds:
-      resource = DataFeedApplier(self.client, id_map).apply(data_service_id, dataflow.id, df,
-                                                            dry_run)
+      resource = DataFeedApplier(self.client, id_map).apply(data_service_id, dataflow.id, df, dry_run)
       id_map[df.id] = ComponentUuidType(type=df.legacy_type(), uuid=resource.uuid)
 
     for group in dataflow.groups:
@@ -187,9 +186,11 @@ class DataflowApplier:
       g.add_node(component.id)
       if component.type == "view":
         for input in component.inputs:
-          g.add_edge(component.id, uuid_to_id[input.uuid])
+          if input.type in ["source", "view"]:
+            g.add_edge(component.id, uuid_to_id[input.uuid])
       elif component.type == "sink":
-        g.add_edge(component.id, uuid_to_id[component.inputUUID])
+        if component.inputType in ["source", "view"]:
+          g.add_edge(component.id, uuid_to_id[component.inputUUID])
 
     expected_components = [component.id for component in dataflow.components]
     for component_id in list(nx.topological_sort(g)):
@@ -203,8 +204,7 @@ class DataflowApplier:
           if not dry_run:
             self.client.delete_transform(data_service_id, dataflow.id, component_id)
         elif id_to_type[component_id] == "sink":
-          glog.info(
-              f"Delete WriteConnector: (ds={data_service_id} df={dataflow.id} {component_id})")
+          glog.info(f"Delete WriteConnector: (ds={data_service_id} df={dataflow.id} {component_id})")
           if not dry_run:
             self.client.delete_write_connector(data_service_id, dataflow.id, component_id)
 
@@ -234,15 +234,13 @@ class GroupApplier:
     if exists:
       glog.info(f"Update ComponentGroup: (ds={data_service_id} df={dataflow_id} {group.id})")
       if not dry_run:
-        return self.client.update_component_group(data_service_id, dataflow_id, group.id,
-                                                  group.to_proto(self.id_map)).data
+        return self.client.update_component_group(data_service_id, dataflow_id, group.id, group.to_proto(self.id_map)).data
       else:
         return api_pb2.ComponentGroup()
     else:
       glog.info(f"Create ComponentGroup: (ds={data_service_id} df={dataflow_id} {group.id})")
       if not dry_run:
-        return self.client.create_component_group(data_service_id, dataflow_id,
-                                                  group.to_proto(self.id_map)).data
+        return self.client.create_component_group(data_service_id, dataflow_id, group.to_proto(self.id_map)).data
       else:
         return api_pb2.ComponentGroup()
 
@@ -269,25 +267,18 @@ class DataFeedApplier:
 
     ds_uuid_to_id = {ds.uuid: ds.id for ds in self.client.list_data_services().data}
     roles = self.client.list_data_service_roles().data
-    ds_to_role_map = {
-        ds_uuid_to_id[role.org_id]: role.uuid
-        for role in roles if role.id == 'Everyone'
-    }
+    ds_to_role_map = {ds_uuid_to_id[role.org_id]: role.uuid for role in roles if role.id == 'Everyone'}
 
     if exists:
       glog.info(f"Update DataFeed: (ds={data_service_id} df={dataflow_id} {data_feed.id})")
       if not dry_run:
-        return self.client.update_data_feed(
-            data_service_id, dataflow_id, data_feed.id,
-            data_feed.to_proto(data_service_id, self.id_map, ds_to_role_map)).data
+        return self.client.update_data_feed(data_service_id, dataflow_id, data_feed.id, data_feed.to_proto(data_service_id, self.id_map, ds_to_role_map)).data
       else:
         return api_pb2.DataFeed()
     else:
       glog.info(f"Create DataFeed: (ds={data_service_id} df={dataflow_id} {data_feed.id})")
       if not dry_run:
-        return self.client.create_data_feed(
-            data_service_id, dataflow_id,
-            data_feed.to_proto(data_service_id, self.id_map, ds_to_role_map)).data
+        return self.client.create_data_feed(data_service_id, dataflow_id, data_feed.to_proto(data_service_id, self.id_map, ds_to_role_map)).data
       else:
         return api_pb2.DataFeed()
 
@@ -301,14 +292,9 @@ class DataFeedConnectorApplier:
   def __init__(self, client: Client):
     self.client = client
 
-  def apply(self,
-            data_service_id,
-            dataflow_id,
-            data_feed_connector: DataFeedConnector,
-            dry_run=False):
+  def apply(self, data_service_id, dataflow_id, data_feed_connector: DataFeedConnector, dry_run=False):
     try:
-      data_feed = self.client.get_data_feed(data_feed_connector.input_data_service_id,
-                                            data_feed_connector.input_dataflow_id,
+      data_feed = self.client.get_data_feed(data_feed_connector.input_data_service_id, data_feed_connector.input_dataflow_id,
                                             data_feed_connector.input_data_feed_id).data
     except ApiException as e:
       if e.status == 404 and dry_run and \
@@ -331,17 +317,13 @@ class DataFeedConnectorApplier:
     if exists:
       glog.info(f"Update DataFeedConnector: {dfc_repr}")
       if not dry_run:
-        return self.client.update_data_feed_connector(
-            data_service_id, dataflow_id, data_feed_connector.id,
-            data_feed_connector.to_proto(data_feed.uuid)).data
+        return self.client.update_data_feed_connector(data_service_id, dataflow_id, data_feed_connector.id, data_feed_connector.to_proto(data_feed.uuid)).data
       else:
         return api_pb2.DataFeedConnector()
     else:
       glog.info(f"Create DataFeedConnector: {dfc_repr}")
       if not dry_run:
-        return self.client.create_data_feed_connector(data_service_id, dataflow_id,
-                                                      data_feed_connector.to_proto(
-                                                          data_feed.uuid)).data
+        return self.client.create_data_feed_connector(data_service_id, dataflow_id, data_feed_connector.to_proto(data_feed.uuid)).data
       else:
         return api_pb2.DataFeedConnector()
 
@@ -361,9 +343,7 @@ class ComponentApplier:
       elif isinstance(component, Transform):
         self.client.get_transform(data_service_id, dataflow_id, component.id)
       else:
-        raise TypeError(
-            "Component has type {}, but expected one of: ReadConnector, WriteConnector, Transform".
-            format(type(component)))
+        raise TypeError("Component has type {}, but expected one of: ReadConnector, WriteConnector, Transform".format(type(component)))
       return True
     except ApiException as e:
       if e.status == 404:
@@ -397,15 +377,13 @@ class ComponentApplier:
     if isinstance(component, ReadConnector):
       glog.info(f"Update ReadConnector: (ds={data_service_id} df={dataflow_id} {component.id})")
       if not self.dry_run:
-        return self.client.update_read_connector(data_service_id, dataflow_id, component.id,
-                                                 proto).data
+        return self.client.update_read_connector(data_service_id, dataflow_id, component.id, proto).data
       else:
         return api_pb2.ReadConnector()
     elif isinstance(component, WriteConnector):
       glog.info(f"Update WriteConnector: (ds={data_service_id} df={dataflow_id} {component.id})")
       if not self.dry_run:
-        return self.client.update_write_connector(data_service_id, dataflow_id, component.id,
-                                                  proto).data
+        return self.client.update_write_connector(data_service_id, dataflow_id, component.id, proto).data
       else:
         return api_pb2.WriteConnector()
     elif isinstance(component, Transform):
@@ -447,8 +425,7 @@ def _component_id_map_from_list(components: List[Component]) -> Dict[str, Compon
   return id_to_component
 
 
-def _component_id_to_uuid_map(client: Client, data_service_id: str,
-                              dataflow_id: str) -> ComponentIdToUuidMap:
+def _component_id_to_uuid_map(client: Client, data_service_id: str, dataflow_id: str) -> ComponentIdToUuidMap:
   id_map: ComponentIdToUuidMap = {}
   components = client.list_dataflow_components(data_service_id, dataflow_id).data
   for c in components:
