@@ -10,9 +10,8 @@ from typing import Dict
 
 import ascend.protos.api.api_pb2 as api_pb2
 from ascend.sdk.client import Client
-from ascend.sdk.definitions import (Dataflow, ReadConnector, Transform, WriteConnector,
-                                    ComponentGroup, ComponentUuidToIdMap, DataFeed,
-                                    DataFeedConnector, DataService)
+from ascend.sdk.definitions import (Dataflow, ReadConnector, Transform, WriteConnector, ComponentGroup, ComponentUuidToIdMap, DataFeed, DataFeedConnector,
+                                    DataService)
 
 
 def data_service_from_proto(client: Client, proto: api_pb2.DataService) -> 'DataService':
@@ -32,15 +31,11 @@ def data_service_from_proto(client: Client, proto: api_pb2.DataService) -> 'Data
       id=proto.id,
       name=proto.name,
       description=proto.description,
-      dataflows=[
-          dataflow_from_proto(client, proto.id, dataflow_proto)
-          for dataflow_proto in dataflow_protos
-      ],
+      dataflows=[dataflow_from_proto(client, proto.id, dataflow_proto) for dataflow_proto in dataflow_protos],
   )
 
 
-def dataflow_from_proto(client: Client, data_service_id: str,
-                        proto: api_pb2.Dataflow) -> 'Dataflow':
+def dataflow_from_proto(client: Client, data_service_id: str, proto: api_pb2.Dataflow) -> 'Dataflow':
   """
   Build a Dataflow definition from the API Dataflow protobuf representation.
 
@@ -58,19 +53,13 @@ def dataflow_from_proto(client: Client, data_service_id: str,
 
   read_connectors = [
       ReadConnector.from_proto(client.get_read_connector(data_service_id, proto.id, c.id).data)
-      if c.source.container.HasField('immediate') else ReadConnector.from_proto(c)
-      for c in component_protos if c.type == "source"
+      if c.source.container.HasField('immediate') else ReadConnector.from_proto(c) for c in component_protos if c.type == "source"
   ]
   transforms = [Transform.from_proto(c, uuid_map) for c in component_protos if c.type == "view"]
-  write_connectors = [
-      WriteConnector.from_proto(c, uuid_map) for c in component_protos if c.type == "sink"
-  ]
+  write_connectors = [WriteConnector.from_proto(c, uuid_map) for c in component_protos if c.type == "sink"]
 
   role_to_ds_map = _role_to_ds_map(client)
-  data_feeds = [
-      DataFeed.from_proto(c, data_service_id, role_to_ds_map, uuid_map) for c in component_protos
-      if c.type == "pub"
-  ]
+  data_feeds = [DataFeed.from_proto(c, data_service_id, role_to_ds_map, uuid_map) for c in component_protos if c.type == "pub"]
 
   data_feed_connectors = []
   groups = []
@@ -86,11 +75,7 @@ def dataflow_from_proto(client: Client, data_service_id: str,
                             input_data_feed_id=df.id))
     elif c.type == "group":
       component_ids = [uuid_map[input.uuid] for input in c.content]
-      groups.append(
-          ComponentGroup(id=c.id,
-                         name=c.name,
-                         description=c.description,
-                         component_ids=component_ids))
+      groups.append(ComponentGroup(id=c.id, name=c.name, description=c.description, component_ids=component_ids))
 
   return Dataflow(
       id=proto.id,
@@ -106,7 +91,4 @@ def dataflow_from_proto(client: Client, data_service_id: str,
 def _role_to_ds_map(client: Client) -> Dict[str, str]:
   ds_uuid_to_id = {ds.uuid: ds.id for ds in client.list_data_services().data}
   roles = client.list_data_service_roles().data
-  return {
-      role.uuid: ds_uuid_to_id[role.org_id]
-      for role in roles if role.org_id in ds_uuid_to_id and role.id == 'Everyone'
-  }
+  return {role.uuid: ds_uuid_to_id[role.org_id] for role in roles if role.org_id in ds_uuid_to_id and role.id == 'Everyone'}
