@@ -91,11 +91,7 @@ class ReadConnector(Component):
     return []
 
   def to_proto(self, id_map: ComponentIdToUuidMap):
-    proto = api_pb2.ReadConnector(id=self.id,
-                                  name=self.name,
-                                  description=self.description,
-                                  version=1,
-                                  source=component_pb2.Source(container=self.container))
+    proto = api_pb2.ReadConnector(id=self.id, name=self.name, description=self.description, version=1, source=component_pb2.Source(container=self.container))
     if self.pattern is not None:
       proto.source.pattern.CopyFrom(self.pattern)
     if self.update_periodical is not None:
@@ -118,10 +114,7 @@ class ReadConnector(Component):
 
   @staticmethod
   def from_proto(proto: api_pb2.ReadConnector) -> 'ReadConnector':
-    rc = ReadConnector(id=proto.id,
-                       name=proto.name,
-                       description=proto.description,
-                       container=proto.source.container)
+    rc = ReadConnector(id=proto.id, name=proto.name, description=proto.description, container=proto.source.container)
     if proto.source.HasField("bytes"):
       rc.bytes = proto.source.bytes
     elif proto.source.HasField("records"):
@@ -172,10 +165,7 @@ class Transform(Component):
 
   def to_proto(self, id_map: ComponentIdToUuidMap):
     try:
-      inputs = [
-          api_pb2.Transform.Input(type=id_map[dep].type, uuid=id_map[dep].uuid)
-          for dep in self.dependencies()
-      ]
+      inputs = [api_pb2.Transform.Input(type=id_map[dep].type, uuid=id_map[dep].uuid) for dep in self.dependencies()]
     except KeyError as e:
       raise KeyError(f"unresolved uuid for component {e}")
     proto = api_pb2.Transform(id=self.id,
@@ -248,11 +238,7 @@ class WriteConnector(Component):
     return [self.input_id]
 
   def to_proto(self, id_map: ComponentIdToUuidMap):
-    proto = api_pb2.WriteConnector(id=self.id,
-                                   name=self.name,
-                                   description=self.description,
-                                   version=1,
-                                   sink=component_pb2.Sink(container=self.container))
+    proto = api_pb2.WriteConnector(id=self.id, name=self.name, description=self.description, version=1, sink=component_pb2.Sink(container=self.container))
     try:
       proto.inputType = id_map[self.input_id].type
       proto.inputUUID = id_map[self.input_id].uuid
@@ -274,11 +260,7 @@ class WriteConnector(Component):
   @staticmethod
   def from_proto(proto: api_pb2.WriteConnector, uuid_map: ComponentUuidToIdMap) -> 'WriteConnector':
     try:
-      wc = WriteConnector(id=proto.id,
-                          name=proto.name,
-                          description=proto.description,
-                          container=proto.sink.container,
-                          input_id=uuid_map[proto.inputUUID])
+      wc = WriteConnector(id=proto.id, name=proto.name, description=proto.description, container=proto.sink.container, input_id=uuid_map[proto.inputUUID])
       if proto.sink.HasField("bytes"):
         wc.bytes = proto.sink.bytes
       elif proto.sink.HasField("records"):
@@ -327,8 +309,7 @@ class DataFeed(Definition):
     self.data_services_shared_with = data_services_shared_with
     self.hidden_from_host_data_service = hidden_from_host_data_service
 
-  def to_proto(self, host_data_service_id: str, id_map: ComponentIdToUuidMap,
-               ds_to_role_map: Dict[str, str]):
+  def to_proto(self, host_data_service_id: str, id_map: ComponentIdToUuidMap, ds_to_role_map: Dict[str, str]):
     proto = api_pb2.DataFeed(
         id=self.id,
         name=self.name,
@@ -361,13 +342,9 @@ class DataFeed(Definition):
     return "pub"
 
   @staticmethod
-  def from_proto(proto: api_pb2.DataFeed, host_data_service: str, role_to_ds_map: Dict[str, str],
-                 uuid_map: ComponentUuidToIdMap) -> 'DataFeed':
+  def from_proto(proto: api_pb2.DataFeed, host_data_service: str, role_to_ds_map: Dict[str, str], uuid_map: ComponentUuidToIdMap) -> 'DataFeed':
     try:
-      df = DataFeed(id=proto.id,
-                    name=proto.name,
-                    description=proto.description,
-                    input_id=uuid_map[proto.inputUUID])
+      df = DataFeed(id=proto.id, name=proto.name, description=proto.description, input_id=uuid_map[proto.inputUUID])
       if proto.open:
         df.shared_with_all = True
       else:
@@ -382,13 +359,7 @@ class DataFeed(Definition):
 
 class DataFeedConnector(Definition):
   """A data feed connector"""
-  def __init__(self,
-               id: str,
-               name: str,
-               input_data_service_id: str,
-               input_dataflow_id: str,
-               input_data_feed_id: str,
-               description: str = None):
+  def __init__(self, id: str, name: str, input_data_service_id: str, input_dataflow_id: str, input_data_feed_id: str, description: str = None):
     """
     Create a DataFeedConnector definition.
 
@@ -409,10 +380,7 @@ class DataFeedConnector(Definition):
     self.input_data_feed_id = input_data_feed_id
 
   def to_proto(self, data_feed_uuid: str):
-    return api_pb2.DataFeedConnector(id=self.id,
-                                     name=self.name,
-                                     description=self.description,
-                                     pubUUID=data_feed_uuid)
+    return api_pb2.DataFeedConnector(id=self.id, name=self.name, description=self.description, pubUUID=data_feed_uuid)
 
   def legacy_type(self) -> str:
     return "sub"
@@ -438,24 +406,15 @@ class ComponentGroup(Definition):
 
   def to_proto(self, id_map: ComponentIdToUuidMap):
     try:
-      content = [
-          api_pb2.ComponentGroup.Input(type=id_map[id].type, uuid=id_map[id].uuid)
-          for id in self.component_ids
-      ]
+      content = [api_pb2.ComponentGroup.Input(type=id_map[id].type, uuid=id_map[id].uuid) for id in self.component_ids]
     except KeyError as e:
       raise KeyError(f"unresolved uuid for component {e}")
-    return api_pb2.ComponentGroup(id=self.id,
-                                  name=self.name,
-                                  description=self.description,
-                                  content=content)
+    return api_pb2.ComponentGroup(id=self.id, name=self.name, description=self.description, content=content)
 
   @staticmethod
   def from_proto(proto: api_pb2.ComponentGroup, uuid_map: ComponentUuidToIdMap) -> 'ComponentGroup':
     try:
-      return ComponentGroup(id=proto.id,
-                            name=proto.name,
-                            description=proto.description,
-                            component_ids=[uuid_map[input.uuid] for input in proto.content])
+      return ComponentGroup(id=proto.id, name=proto.name, description=proto.description, component_ids=[uuid_map[input.uuid] for input in proto.content])
     except KeyError as e:
       raise KeyError(f"unresolved id for component {e}")
 
