@@ -22,12 +22,7 @@ class InlineCode:
   a component definition, with the inline code written to a separate file, and a reference
   to this code stored in the component.
   """
-  def __init__(self,
-               code: str,
-               attribute_path: Tuple[str, ...],
-               resource_path: str,
-               base_path: str,
-               base64_encoded: bool = False):
+  def __init__(self, code: str, attribute_path: Tuple[str, ...], resource_path: str, base_path: str, base64_encoded: bool = False):
     """
     Parameters:
     - code: inline code
@@ -51,11 +46,7 @@ class InlineCode:
       return f'''pathlib.Path(os.path.join(os.path.dirname(os.path.realpath(__file__)), "{self._rel_path}")).read_text()'''
 
 
-def download_dataflow(client: Client,
-                      data_service_id: str,
-                      dataflow_id: str,
-                      hostname: str,
-                      resource_base_path: str = "."):
+def download_dataflow(client: Client, data_service_id: str, dataflow_id: str, hostname: str, resource_base_path: str = "."):
   """
   Downloads a Dataflow and writes its definition to a file named `{dataflow_id}.py` under
   `resource_base_path`. Inline code for Transforms and ReadConnectors are written as separate
@@ -79,13 +70,11 @@ def download_dataflow(client: Client,
 
   dataflow_resource_path = os.path.join(resource_base_path, f"{dataflow.id}")
   dataflow_path = os.path.join(resource_base_path, f"{dataflow.id}.py")
-  glog.info(f"Writing dataflow definition to ({dataflow_path})"
-            f" and dataflow resource files to ({dataflow_resource_path})")
+  glog.info(f"Writing dataflow definition to ({dataflow_path})" f" and dataflow resource files to ({dataflow_resource_path})")
 
   pathlib.Path(dataflow_resource_path).mkdir(parents=True, exist_ok=True)
 
-  rendered_dataflow, inline_code_list = render_dataflow(data_service_id, dataflow, hostname,
-                                                        dataflow_resource_path, resource_base_path)
+  rendered_dataflow, inline_code_list = render_dataflow(data_service_id, dataflow, hostname, dataflow_resource_path, resource_base_path)
   for inline_code in inline_code_list:
     with open(inline_code.resource_path, "w") as f:
       f.write(inline_code.code)
@@ -94,10 +83,7 @@ def download_dataflow(client: Client,
     f.write(rendered_dataflow)
 
 
-def download_data_service(client: Client,
-                          data_service_id: str,
-                          hostname: str,
-                          resource_base_path: str = "."):
+def download_data_service(client: Client, data_service_id: str, hostname: str, resource_base_path: str = "."):
   """
   Downloads a DataService and writes its definition to a file named `{data_service_id}.py`
   under `resource_base_path`. Inline code for Transforms and ReadConnectors are written as separate
@@ -119,17 +105,13 @@ def download_data_service(client: Client,
   data_service = data_service_from_proto(client, ds_proto)
 
   data_service_path = os.path.join(resource_base_path, f"{data_service.id}.py")
-  dataflow_resource_paths = [
-      os.path.join(resource_base_path, f"{dataflow.id}") for dataflow in data_service.dataflows
-  ]
-  glog.info(f"Writing data service definition to ({data_service_path})"
-            f" and dataflow resource files to ({','.join(dataflow_resource_paths)})")
+  dataflow_resource_paths = [os.path.join(resource_base_path, f"{dataflow.id}") for dataflow in data_service.dataflows]
+  glog.info(f"Writing data service definition to ({data_service_path})" f" and dataflow resource files to ({','.join(dataflow_resource_paths)})")
 
   for path in dataflow_resource_paths:
     pathlib.Path(path).mkdir(parents=True, exist_ok=True)
 
-  rendered_data_service, inline_code_list = render_data_service(data_service, hostname,
-                                                                resource_base_path)
+  rendered_data_service, inline_code_list = render_data_service(data_service, hostname, resource_base_path)
   for inline_code in inline_code_list:
     with open(inline_code.resource_path, "w") as f:
       f.write(inline_code.code)
@@ -148,8 +130,7 @@ class InlineCodeMap:
       self._inline_code_map[(dataflow_id, component_id)] = []
     self._inline_code_map[(dataflow_id, component_id)].append(inline_code)
 
-  def attribute_path_to_loader(self, dataflow_id: str,
-                               component_id: str) -> Dict[Tuple[str, ...], str]:
+  def attribute_path_to_loader(self, dataflow_id: str, component_id: str) -> Dict[Tuple[str, ...], str]:
     if (dataflow_id, component_id) in self._inline_code_map:
       inline_code_list = self._inline_code_map[(dataflow_id, component_id)]
       return {ic.attribute_path: ic.loader() for ic in inline_code_list}
@@ -157,8 +138,7 @@ class InlineCodeMap:
       return {}
 
 
-def render_dataflow(data_service_id: str, dataflow: Dataflow, hostname: str, resource_path: str,
-                    base_path: str) -> Tuple[str, List[InlineCode]]:
+def render_dataflow(data_service_id: str, dataflow: Dataflow, hostname: str, resource_path: str, base_path: str) -> Tuple[str, List[InlineCode]]:
   inline_code_list: List[InlineCode] = []
   inline_code_map = InlineCodeMap()
 
@@ -207,30 +187,18 @@ def render_data_service(data_service: DataService, hostname: str, resource_path:
   return rendered, inline_code_list
 
 
-_proto_mods = [
-    "ascend", "component", "content_encoding", "core", "expression", "format", "function", "io",
-    "operator", "pattern", "schema", "text"
-]
+_proto_mods = ["ascend", "component", "content_encoding", "core", "expression", "format", "function", "io", "operator", "pattern", "schema", "text"]
 
-_gmod_classes = [("google.protobuf.wrappers_pb2", "DoubleValue"),
-                 ("google.protobuf.wrappers_pb2", "BoolValue"),
-                 ("google.protobuf.wrappers_pb2", "Int64Value"),
-                 ("google.protobuf.wrappers_pb2", "UInt64Value"),
-                 ("google.protobuf.wrappers_pb2", "Int32Value"),
-                 ("google.protobuf.wrappers_pb2", "UInt32Value"),
-                 ("google.protobuf.duration_pb2", "Duration"),
-                 ("google.protobuf.timestamp_pb2", "Timestamp"),
-                 ("google.protobuf.struct_pb2", "NullValue"),
-                 ("google.protobuf.empty_pb2", "Empty")]
+_gmod_classes = [("google.protobuf.wrappers_pb2", "DoubleValue"), ("google.protobuf.wrappers_pb2", "BoolValue"), ("google.protobuf.wrappers_pb2", "Int64Value"),
+                 ("google.protobuf.wrappers_pb2", "UInt64Value"), ("google.protobuf.wrappers_pb2", "Int32Value"),
+                 ("google.protobuf.wrappers_pb2", "UInt32Value"), ("google.protobuf.duration_pb2", "Duration"), ("google.protobuf.timestamp_pb2", "Timestamp"),
+                 ("google.protobuf.struct_pb2", "NullValue"), ("google.protobuf.empty_pb2", "Empty")]
 
 
 def _classname_map() -> dict:
   classname_map: dict = {}
 
-  for defclass in [
-      'DataService', 'Dataflow', 'ReadConnector', 'WriteConnector', 'Transform', 'ComponentGroup',
-      'DataFeed', 'DataFeedConnector'
-  ]:
+  for defclass in ['DataService', 'Dataflow', 'ReadConnector', 'WriteConnector', 'Transform', 'ComponentGroup', 'DataFeed', 'DataFeedConnector']:
     classname_map[defclass] = f"definitions.{defclass}"
 
   for _, cls in _gmod_classes:
@@ -239,18 +207,14 @@ def _classname_map() -> dict:
   return classname_map
 
 
-def _inline_code_list_for(component: Component, resource_path_prefix: str,
-                          base_path: str) -> Optional[List[InlineCode]]:
+def _inline_code_list_for(component: Component, resource_path_prefix: str, base_path: str) -> Optional[List[InlineCode]]:
   if isinstance(component, Transform) and component.operator:
-    if component.operator.HasField(
-        "spark_function") and component.operator.spark_function.executable.code.source.HasField(
-            "inline"):
+    if component.operator.HasField("spark_function") and component.operator.spark_function.executable.code.source.HasField("inline"):
       return [
           InlineCode(code=component.operator.spark_function.executable.code.source.inline,
                      resource_path=os.path.join(resource_path_prefix, f"{component.id}.py"),
                      base_path=base_path,
-                     attribute_path=("operator", "spark_function", "executable", "code", "source",
-                                     "inline"))
+                     attribute_path=("operator", "spark_function", "executable", "code", "source", "inline"))
       ]
     elif component.operator.HasField("sql_query"):
       return [
@@ -263,27 +227,21 @@ def _inline_code_list_for(component: Component, resource_path_prefix: str,
       return []
   elif isinstance(component, ReadConnector):
     icl = []
-    if component.container and component.container.HasField(
-        "byte_function"
-    ) and component.container.byte_function.container.executable.code.source.HasField("inline"):
+    if component.container and component.container.HasField("byte_function") and component.container.byte_function.container.executable.code.source.HasField(
+        "inline"):
       icl.append(
           InlineCode(
-              code=base64.b64decode(component.container.byte_function.container.executable.code.
-                                    source.inline).decode(),
-              resource_path=os.path.join(resource_path_prefix,
-                                         f"custom_read_connector_{component.id}.py"),  # noqa: E126
+              code=base64.b64decode(component.container.byte_function.container.executable.code.source.inline).decode(),
+              resource_path=os.path.join(resource_path_prefix, f"custom_read_connector_{component.id}.py"),  # noqa: E126
               base_path=base_path,
-              attribute_path=("container", "byte_function", "container", "executable", "code",
-                              "source", "inline"),
+              attribute_path=("container", "byte_function", "container", "executable", "code", "source", "inline"),
               base64_encoded=True))
-    if component.bytes and component.bytes.parser.HasField(
-        "lambda_parser") and component.bytes.parser.lambda_parser.HasField(
-            "code") and component.bytes.parser.lambda_parser.code.HasField("inline"):
+    if component.bytes and component.bytes.parser.HasField("lambda_parser") and component.bytes.parser.lambda_parser.HasField(
+        "code") and component.bytes.parser.lambda_parser.code.HasField("inline"):
       icl.append(
           InlineCode(
               code=base64.b64decode(component.bytes.parser.lambda_parser.code.inline).decode(),
-              resource_path=os.path.join(resource_path_prefix,
-                                         f"custom_parser_{component.id}.py"),  # noqa: E126
+              resource_path=os.path.join(resource_path_prefix, f"custom_parser_{component.id}.py"),  # noqa: E126
               base_path=base_path,
               attribute_path=("bytes", "parser", "lambda_parser", "code", "inline"),
               base64_encoded=True))
@@ -295,16 +253,10 @@ def _inline_code_list_for(component: Component, resource_path_prefix: str,
 def _jinja_env():
   module_dir = os.path.dirname(os.path.abspath(__file__))
   template_dir = os.path.join(module_dir, "templates")
-  return jinja2.Environment(loader=jinja2.FileSystemLoader(template_dir),
-                            trim_blocks=True,
-                            lstrip_blocks=True)
+  return jinja2.Environment(loader=jinja2.FileSystemLoader(template_dir), trim_blocks=True, lstrip_blocks=True)
 
 
-def _render_definition(val: Definition,
-                       attribute_path: Tuple[str, ...] = (),
-                       indent=0,
-                       classname_map: dict = {},
-                       attribute_overrides: dict = {}):
+def _render_definition(val: Definition, attribute_path: Tuple[str, ...] = (), indent=0, classname_map: dict = {}, attribute_overrides: dict = {}):
   defcls = val.__class__.__name__
   cls = classname_map.get(defcls, defcls)
   tmpl = jinja2.Template('''{{cls}}(
@@ -330,11 +282,7 @@ def _render_definition(val: Definition,
                      cls=cls)
 
 
-def _render_value(val,
-                  attribute_path: Tuple[str, ...],
-                  indent=0,
-                  classname_map: dict = {},
-                  attribute_overrides: dict = {}):
+def _render_value(val, attribute_path: Tuple[str, ...], indent=0, classname_map: dict = {}, attribute_overrides: dict = {}):
   """ Renders values in Python definition form. Support is limited to
   resource definitions, proto messages, and native types.
   """
@@ -352,11 +300,7 @@ def _render_value(val,
     return val
 
 
-def _render_array(arr,
-                  attribute_path: Tuple[str, ...],
-                  indent=0,
-                  classname_map: dict = {},
-                  attribute_overrides: dict = {}):
+def _render_array(arr, attribute_path: Tuple[str, ...], indent=0, classname_map: dict = {}, attribute_overrides: dict = {}):
   tmpl = jinja2.Template('''[
 {% for v in arr %}\
 {{_spaces_for(indent+2)}}{{ _render_value(v, attribute_path, indent+2, classname_map, attribute_overrides) }},\n\
@@ -371,11 +315,7 @@ def _render_array(arr,
                      attribute_overrides=attribute_overrides)
 
 
-def _render_map(mp,
-                attribute_path: Tuple[str, ...],
-                indent=0,
-                classname_map: dict = {},
-                attribute_overrides: dict = {}):
+def _render_map(mp, attribute_path: Tuple[str, ...], indent=0, classname_map: dict = {}, attribute_overrides: dict = {}):
   tmpl = jinja2.Template('''{
 {% for k, v in mp.items() %}\
 {{_spaces_for(indent+2)}}{{_render_value(k, attribute_path, indent+2, classname_map, attribute_overrides)}}: \
@@ -391,11 +331,7 @@ def _render_map(mp,
                      attribute_overrides=attribute_overrides)
 
 
-def _render_message(message: ProtoMessage,
-                    attribute_path: Tuple[str, ...],
-                    indent=0,
-                    classname_map: dict = {},
-                    attribute_overrides: dict = {}):
+def _render_message(message: ProtoMessage, attribute_path: Tuple[str, ...], indent=0, classname_map: dict = {}, attribute_overrides: dict = {}):
   def render_message_field(field_descriptor, val, attribute_path, indent):
     if field_descriptor.label == descriptor.FieldDescriptor.LABEL_REPEATED:
       if hasattr(val, 'items'):
@@ -444,7 +380,9 @@ def _components_ordered_by_dependency(components: List[Component]) -> List[Compo
   for component in components:
     g.add_node(component.id)
     for dep in component.dependencies():
-      g.add_edge(component.id, dep)
+      # A data feed connector will not be in the component list.
+      if dep in id_to_component:
+        g.add_edge(component.id, dep)
 
   for component_id in reversed(list(nx.topological_sort(g))):
     component = id_to_component[component_id]
